==> mrpt_0.9.4.orig.tar.gz: mrpt-0.9.4/libs/base/src/utils/mrpt_font_6x13.h <==
/* +---------------------------------------------------------------------------+
   |          The Mobile Robot Programming Toolkit (MRPT) C++ library          |
   |                                                                           |
   |                   http://mrpt.sourceforge.net/                            |
   |                                                                           |
   |   Copyright (C) 2005-2011  University of Malaga                           |
   |                                                                           |
   |    This software was written by the Machine Perception and Intelligent    |
   |      Robotics Lab, University of Malaga (Spain).                          |
   |    Contact: Jose-Luis Blanco  <jlblanco@ctima.uma.es>                     |
   |                                                                           |
   |  This file is part of the MRPT project.                                   |
   |                                                                           |
   |     MRPT is free software: you can redistribute it and/or modify          |
   |     it under the terms of the GNU General Public License as published by  |
   |     the Free Software Foundation, either version 3 of the License, or     |
   |     (at your option) any later version.                                   |
   |                                                                           |
   |   MRPT is distributed in the hope that it will be useful,                 |
   |     but WITHOUT ANY WARRANTY; without even the implied warranty of        |
   |     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         |
   |     GNU General Public License for more details.                          |
   |                                                                           |
   |     You should have received a copy of the GNU General Public License     |
   |     along with MRPT.  If not, see <http://www.gnu.org/licenses/>.         |
   |                                                                           |
   +---------------------------------------------------------------------------+ */

static const unsigned char mrpt_font_gz_6x13 [] = {
31,139,8,0,0,0,0,0,4,3,237,153,217,142,35,55,
12,69,59,219,100,223,247,253,255,191,50,209,233,246,65,174,
239,176,202,26,204,0,121,41,2,50,89,18,73,81,151,148,
74,182,95,61,61,61,125,185,26,244,207,11,123,254,252,241,
38,127,123,192,29,15,147,75,188,16,184,16,184,16,184,16,
184,16,248,95,16,248,112,205,122,212,8,136,177,166,207,86,
135,173,199,206,158,181,249,251,102,47,167,127,34,230,254,107,
181,143,110,237,171,197,127,184,181,175,23,159,98,251,110,245,
243,158,197,231,39,55,157,247,111,207,244,127,186,218,68,232,
56,143,242,175,171,15,253,159,6,131,196,108,24,126,173,203,
88,176,195,127,55,253,161,39,161,147,253,140,101,115,12,189,
36,250,89,43,120,193,121,222,37,125,146,27,229,93,219,212,
251,226,102,223,177,165,14,50,243,188,13,17,35,235,236,53,
126,179,250,104,226,197,184,152,191,183,100,90,19,58,212,13,
247,183,110,244,247,28,171,235,185,239,213,226,212,14,227,221,
166,245,17,175,254,141,17,59,226,35,174,201,134,190,212,197,
135,107,196,23,207,77,174,157,92,16,63,141,122,198,151,99,
75,188,35,198,196,135,59,238,247,171,61,154,199,245,104,199,
222,116,125,71,177,229,122,136,69,220,204,209,84,55,206,163,
239,233,121,185,186,163,214,225,60,121,180,30,29,16,19,246,
112,105,234,115,12,62,141,31,237,133,204,167,185,135,227,3,
76,24,63,35,48,148,82,182,79,78,94,218,175,152,59,175,
186,242,196,45,227,20,11,185,250,240,180,225,236,228,236,161,
81,71,196,0,246,77,248,233,61,199,90,204,49,188,137,250,
226,156,183,49,175,50,156,241,38,99,179,70,147,31,213,104,
207,147,115,28,205,67,236,233,27,31,249,60,229,233,145,13,
246,77,211,122,192,92,220,24,111,114,76,222,56,211,223,132,
31,114,116,212,166,121,254,88,250,158,47,205,57,127,56,47,
155,140,137,113,206,210,15,110,156,103,199,150,120,71,137,235,
36,79,88,235,235,247,229,201,250,180,79,126,55,201,122,160,
159,115,144,166,13,88,39,222,235,241,142,204,143,62,155,79,
184,81,43,169,215,181,115,86,7,105,167,76,172,204,211,231,
200,52,15,152,159,97,237,122,196,89,191,248,102,190,105,61,
224,127,84,55,246,47,149,59,50,246,35,62,205,211,186,190,
235,224,187,243,152,87,57,182,77,206,163,127,124,43,59,182,
99,99,76,242,182,1,55,207,220,60,167,61,171,187,174,193,
132,177,71,173,177,51,151,218,17,143,251,149,249,187,110,176,
119,252,140,247,60,226,4,70,239,146,18,7,99,127,27,255,
196,205,154,121,79,17,43,251,123,186,251,139,27,188,247,18,
118,244,157,17,243,160,167,31,228,198,12,123,115,144,49,161,
107,155,222,167,216,73,206,3,78,204,117,52,15,247,19,222,
103,214,1,241,43,203,87,215,33,57,79,198,69,204,61,159,
235,133,123,183,212,70,62,77,66,110,33,222,27,200,217,38,
220,208,165,62,33,214,214,181,202,57,71,203,247,80,198,198,
216,244,14,90,221,119,52,197,179,19,155,78,62,95,130,231,
141,28,28,206,232,77,112,211,79,231,167,243,162,94,242,174,
107,158,19,163,212,85,118,223,152,75,158,179,134,213,75,238,
122,210,55,242,25,185,30,240,39,183,103,235,177,126,187,166,
169,119,106,227,140,92,135,252,232,60,72,31,234,194,125,55,
88,191,169,151,178,54,214,0,124,122,255,180,13,58,214,27,
50,126,206,200,121,224,174,101,218,167,233,131,179,3,140,153,
7,44,201,77,158,187,235,241,233,151,213,140,67,206,253,77,
89,142,94,146,253,103,60,245,143,124,182,61,122,73,228,26,
76,217,215,23,93,8,92,8,92,8,92,8,92,8,92,8,
188,188,163,193,161,223,161,249,220,56,49,198,29,140,119,42,
247,100,26,50,125,140,77,212,223,49,62,94,74,222,205,120,
63,115,15,60,34,238,43,248,246,62,229,253,111,210,247,142,
163,46,119,21,98,146,79,241,209,151,13,191,249,220,54,185,
22,101,239,147,220,167,148,241,35,25,143,207,59,220,117,130,
45,191,87,241,251,147,191,91,137,201,228,7,59,226,240,62,
238,247,196,190,183,77,182,252,191,70,172,230,21,153,190,29,
194,191,247,253,29,125,116,136,245,140,196,224,231,165,196,218,
105,202,103,24,236,172,181,231,237,92,246,248,209,179,181,210,
53,54,197,64,205,131,45,54,200,236,131,71,164,13,28,187,
190,223,78,246,222,217,167,177,221,62,247,146,156,239,12,96,
239,119,53,253,80,95,244,103,227,119,19,255,171,221,169,31,
176,127,23,148,235,6,47,176,130,211,118,176,94,106,207,53,
233,154,179,198,166,124,162,159,68,110,221,51,185,151,82,7,
121,138,141,189,195,119,36,236,248,13,157,231,164,201,134,245,
162,143,46,50,118,73,216,16,19,156,218,65,230,124,58,155,
103,13,63,235,202,173,85,242,46,46,189,111,245,175,13,24,
168,11,110,202,140,75,153,43,230,216,177,113,143,226,99,215,
198,60,188,137,13,177,208,160,221,121,212,131,43,187,238,35,
12,240,255,219,106,228,197,198,187,144,90,245,249,207,37,55,
121,46,186,23,147,51,39,227,196,64,94,160,204,15,177,168,
159,191,235,116,125,103,126,118,109,50,63,187,54,137,245,174,
77,174,199,181,138,187,188,107,52,215,179,107,147,235,217,181,
201,245,236,218,144,35,114,193,222,180,113,158,42,195,25,79,
202,186,182,206,252,143,138,179,218,190,180,105,220,212,73,254,
8,183,212,85,110,155,198,77,189,228,109,147,235,97,44,117,
149,219,166,177,86,47,121,219,36,30,200,232,226,39,247,44,
253,73,156,175,248,1,87,26,119,50,155,255,13,50,206,190,
146,18,235,140,39,229,142,45,107,52,245,82,110,155,196,58,
245,82,110,155,196,45,245,82,110,155,41,54,113,115,207,193,
155,192,132,218,77,223,121,238,36,102,218,242,219,174,191,211,
123,14,242,172,143,233,251,66,226,77,236,228,204,59,48,57,
155,254,203,201,53,237,218,36,222,187,54,93,219,59,177,101,
142,118,230,49,46,56,180,99,243,162,249,223,39,54,196,10,
7,119,106,156,56,206,8,93,242,226,59,5,153,62,106,129,
156,72,157,31,244,60,239,181,81,87,222,249,217,177,17,7,
124,24,219,163,121,26,235,157,121,114,61,211,127,65,204,221,
148,235,217,181,201,245,236,218,228,122,118,108,208,39,95,232,
18,163,184,129,131,109,90,79,214,181,255,229,168,47,95,46,
238,40,113,219,157,39,113,219,181,73,220,118,109,114,61,187,
54,137,245,174,13,128,120,102,34,83,159,80,246,189,244,188,
254,153,239,162,124,7,49,119,159,165,137,181,249,144,239,156,
137,234,202,143,108,18,107,117,229,71,54,137,155,186,242,35,
155,172,3,117,225,234,131,13,207,96,145,228,217,212,53,202,
187,155,62,199,181,57,138,237,108,158,127,1,156,249,163,199,
24,52,0,0,};

==> mrpt_1.0.0.orig.tar.gz: mrpt-1.0.0/libs/base/src/utils/mrpt_font_6x13.h <==
/* +---------------------------------------------------------------------------+
   |                 The Mobile Robot Programming Toolkit (MRPT)               |
   |                                                                           |
   |                          http://www.mrpt.org/                             |
   |                                                                           |
   | Copyright (c) 2005-2013, Individual contributors, see AUTHORS file        |
   | Copyright (c) 2005-2013, MAPIR group, University of Malaga                |
   | Copyright (c) 2012-2013, University of Almeria                            |
   | All rights reserved.                                                      |
   |                                                                           |
   | Redistribution and use in source and binary forms, with or without        |
   | modification, are permitted provided that the following conditions are    |
   | met:                                                                      |
   |    * Redistributions of source code must retain the above copyright       |
   |      notice, this list of conditions and the following disclaimer.        |
   |    * Redistributions in binary form must reproduce the above copyright    |
   |      notice, this list of conditions and the following disclaimer in the  |
   |      documentation and/or other materials provided with the distribution. |
   |    * Neither the name of the copyright holders nor the                    |
   |      names of its contributors may be used to endorse or promote products |
   |      derived from this software without specific prior written permission.|
   |                                                                           |
   | THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS       |
   | 'AS IS' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED |
   | TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR|
   | PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE |
   | FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL|
   | DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR|
   |  SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)       |
   | HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,       |
   | STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN  |
   | ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE           |
   | POSSIBILITY OF SUCH DAMAGE.                                               |
   +---------------------------------------------------------------------------+ */

static const unsigned char mrpt_font_gz_6x13 [] = {
31,139,8,0,0,0,0,0,4,3,237,153,217,142,35,55,
12,69,59,219,100,223,247,253,255,191,50,209,233,246,65,174,
239,176,202,26,204,0,121,41,2,50,89,18,73,81,151,148,
74,182,95,61,61,61,125,185,26,244,207,11,123,254,252,241,
38,127,123,192,29,15,147,75,188,16,184,16,184,16,184,16,
184,16,248,95,16,248,112,205,122,212,8,136,177,166,207,86,
135,173,199,206,158,181,249,251,102,47,167,127,34,230,254,107,
181,143,110,237,171,197,127,184,181,175,23,159,98,251,110,245,
243,158,197,231,39,55,157,247,111,207,244,127,186,218,68,232,
56,143,242,175,171,15,253,159,6,131,196,108,24,126,173,203,
88,176,195,127,55,253,161,39,161,147,253,140,101,115,12,189,
36,250,89,43,120,193,121,222,37,125,146,27,229,93,219,212,
251,226,102,223,177,165,14,50,243,188,13,17,35,235,236,53,
126,179,250,104,226,197,184,152,191,183,100,90,19,58,212,13,
247,183,110,244,247,28,171,235,185,239,213,226,212,14,227,221,
166,245,17,175,254,141,17,59,226,35,174,201,134,190,212,197,
135,107,196,23,207,77,174,157,92,16,63,141,122,198,151,99,
75,188,35,198,196,135,59,238,247,171,61,154,199,245,104,199,
222,116,125,71,177,229,122,136,69,220,204,209,84,55,206,163,
239,233,121,185,186,163,214,225,60,121,180,30,29,16,19,246,
112,105,234,115,12,62,141,31,237,133,204,167,185,135,227,3,
76,24,63,35,48,148,82,182,79,78,94,218,175,152,59,175,
186,242,196,45,227,20,11,185,250,240,180,225,236,228,236,161,
81,71,196,0,246,77,248,233,61,199,90,204,49,188,137,250,
226,156,183,49,175,50,156,241,38,99,179,70,147,31,213,104,
207,147,115,28,205,67,236,233,27,31,249,60,229,233,145,13,
246,77,211,122,192,92,220,24,111,114,76,222,56,211,223,132,
31,114,116,212,166,121,254,88,250,158,47,205,57,127,56,47,
155,140,137,113,206,210,15,110,156,103,199,150,120,71,137,235,
36,79,88,235,235,247,229,201,250,180,79,126,55,201,122,160,
159,115,144,166,13,88,39,222,235,241,142,204,143,62,155,79,
184,81,43,169,215,181,115,86,7,105,167,76,172,204,211,231,
200,52,15,152,159,97,237,122,196,89,191,248,102,190,105,61,
224,127,84,55,246,47,149,59,50,246,35,62,205,211,186,190,
235,224,187,243,152,87,57,182,77,206,163,127,124,43,59,182,
99,99,76,242,182,1,55,207,220,60,167,61,171,187,174,193,
132,177,71,173,177,51,151,218,17,143,251,149,249,187,110,176,
119,252,140,247,60,226,4,70,239,146,18,7,99,127,27,255,
196,205,154,121,79,17,43,251,123,186,251,139,27,188,247,18,
118,244,157,17,243,160,167,31,228,198,12,123,115,144,49,161,
107,155,222,167,216,73,206,3,78,204,117,52,15,247,19,222,
103,214,1,241,43,203,87,215,33,57,79,198,69,204,61,159,
235,133,123,183,212,70,62,77,66,110,33,222,27,200,217,38,
220,208,165,62,33,214,214,181,202,57,71,203,247,80,198,198,
216,244,14,90,221,119,52,197,179,19,155,78,62,95,130,231,
141,28,28,206,232,77,112,211,79,231,167,243,162,94,242,174,
107,158,19,163,212,85,118,223,152,75,158,179,134,213,75,238,
122,210,55,242,25,185,30,240,39,183,103,235,177,126,187,166,
169,119,106,227,140,92,135,252,232,60,72,31,234,194,125,55,
88,191,169,151,178,54,214,0,124,122,255,180,13,58,214,27,
50,126,206,200,121,224,174,101,218,167,233,131,179,3,140,153,
7,44,201,77,158,187,235,241,233,151,213,140,67,206,253,77,
89,142,94,146,253,103,60,245,143,124,182,61,122,73,228,26,
76,217,215,23,93,8,92,8,92,8,92,8,92,8,92,8,
188,188,163,193,161,223,161,249,220,56,49,198,29,140,119,42,
247,100,26,50,125,140,77,212,223,49,62,94,74,222,205,120,
63,115,15,60,34,238,43,248,246,62,229,253,111,210,247,142,
163,46,119,21,98,146,79,241,209,151,13,191,249,220,54,185,
22,101,239,147,220,167,148,241,35,25,143,207,59,220,117,130,
45,191,87,241,251,147,191,91,137,201,228,7,59,226,240,62,
238,247,196,190,183,77,182,252,191,70,172,230,21,153,190,29,
194,191,247,253,29,125,116,136,245,140,196,224,231,165,196,218,
105,202,103,24,236,172,181,231,237,92,246,248,209,179,181,210,
53,54,197,64,205,131,45,54,200,236,131,71,164,13,28,187,
190,223,78,246,222,217,167,177,221,62,247,146,156,239,12,96,
239,119,53,253,80,95,244,103,227,119,19,255,171,221,169,31,
176,127,23,148,235,6,47,176,130,211,118,176,94,106,207,53,
233,154,179,198,166,124,162,159,68,110,221,51,185,151,82,7,
121,138,141,189,195,119,36,236,248,13,157,231,164,201,134,245,
162,143,46,50,118,73,216,16,19,156,218,65,230,124,58,155,
103,13,63,235,202,173,85,242,46,46,189,111,245,175,13,24,
168,11,110,202,140,75,153,43,230,216,177,113,143,226,99,215,
198,60,188,137,13,177,208,160,221,121,212,131,43,187,238,35,
12,240,255,219,106,228,197,198,187,144,90,245,249,207,37,55,
121,46,186,23,147,51,39,227,196,64,94,160,204,15,177,168,
159,191,235,116,125,103,126,118,109,50,63,187,54,137,245,174,
77,174,199,181,138,187,188,107,52,215,179,107,147,235,217,181,
201,245,236,218,144,35,114,193,222,180,113,158,42,195,25,79,
202,186,182,206,252,143,138,179,218,190,180,105,220,212,73,254,
8,183,212,85,110,155,198,77,189,228,109,147,235,97,44,117,
149,219,166,177,86,47,121,219,36,30,200,232,226,39,247,44,
253,73,156,175,248,1,87,26,119,50,155,255,13,50,206,190,
146,18,235,140,39,229,142,45,107,52,245,82,110,155,196,58,
245,82,110,155,196,45,245,82,110,155,41,54,113,115,207,193,
155,192,132,218,77,223,121,238,36,102,218,242,219,174,191,211,
123,14,242,172,143,233,251,66,226,77,236,228,204,59,48,57,
155,254,203,201,53,237,218,36,222,187,54,93,219,59,177,101,
142,118,230,49,46,56,180,99,243,162,249,223,39,54,196,10,
7,119,106,156,56,206,8,93,242,226,59,5,153,62,106,129,
156,72,157,31,244,60,239,181,81,87,222,249,217,177,17,7,
124,24,219,163,121,26,235,157,121,114,61,211,127,65,204,221,
148,235,217,181,201,245,236,218,228,122,118,108,208,39,95,232,
18,163,184,129,131,109,90,79,214,181,255,229,168,47,95,46,
238,40,113,219,157,39,113,219,181,73,220,118,109,114,61,187,
54,137,245,174,13,128,120,102,34,83,159,80,246,189,244,188,
254,153,239,162,124,7,49,119,159,165,137,181,249,144,239,156,
137,234,202,143,108,18,107,117,229,71,54,137,155,186,242,35,
155,172,3,117,225,234,131,13,207,96,145,228,217,212,53,202,
187,155,62,199,181,57,138,237,108,158,127,1,156,249,163,199,
24,52,0,0,};
